@@ -19,8 +19,6 @@
 
 using namespace QApt;
 
-#define BLACKFILE "/usr/share/udcp/appblacklist.txt"
-
 typedef Result<QString> ConflictResult;
 
 class PackageDependsStatus;
@@ -215,6 +213,7 @@ public:
      * @return 包的依赖状态
      */
     PackageDependsStatus getPackageDependsStatus(const int index);
+    bool cachedPackageDependStatus(const int index) const;
 
     /**
      * @brief getPackageOrDepends 解析或依赖关系
@@ -284,7 +283,7 @@ private:
     const PackageDependsStatus checkDependsPackageStatus(QSet<QString> &choosed_set,
                                                          const QString &architecture,
                                                          const QApt::DependencyInfo &dependencyInfo,
-                                                         const QString &providesName = QString::null);
+                                                         const QString &providesName = QString());
     /**
      * @brief packageCandidateChoose   查找包的依赖候选
      * @param choosed_set   包的依赖候选的集合
