@@ -36,10 +36,14 @@
 #include <unistd.h>
 #include <csignal>
 #include <QDebug>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(procLog)
 
 KPtyProcess::KPtyProcess(QObject *parent) :
     KProcess(new KPtyProcessPrivate, parent)
 {
+    qCDebug(procLog) << "KPtyProcess constructed";
     Q_D(KPtyProcess);
 
     d->pty = new KPtyDevice(this);
@@ -47,15 +51,20 @@ KPtyProcess::KPtyProcess(QObject *parent) :
     connect(this, SIGNAL(stateChanged(QProcess::ProcessState)),
             SLOT(_k_onStateChanged(QProcess::ProcessState)));
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    setupChildProcess();
+#else
     // use setChildProcessModifier() replace setupChildProcess()
     setChildProcessModifier([this](){
         setupChildProcessImpl();
     });
+#endif
 }
 
 KPtyProcess::KPtyProcess(int ptyMasterFd, QObject *parent) :
     KProcess(new KPtyProcessPrivate, parent)
 {
+    qCDebug(procLog) << "KPtyProcess constructed with master fd" << ptyMasterFd;
     Q_D(KPtyProcess);
 
     d->pty = new KPtyDevice(this);
@@ -63,21 +72,27 @@ KPtyProcess::KPtyProcess(int ptyMasterFd, QObject *parent) :
     connect(this, SIGNAL(stateChanged(QProcess::ProcessState)),
             SLOT(_k_onStateChanged(QProcess::ProcessState)));
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    setupChildProcess();
+#else
     // use setChildProcessModifier() replace setupChildProcess()
     setChildProcessModifier([this](){
         setupChildProcessImpl();
     });
+#endif
 }
 
 KPtyProcess::~KPtyProcess()
 {
+    qCDebug(procLog) << "KPtyProcess destructed";
     Q_D(KPtyProcess);
 
-    qDebug() << "Process state before cleanup:" << state();
+    qCDebug(procLog) << "Process state before cleanup:" << state();
     if (state() != QProcess::NotRunning)
     {
         if (d->addUtmp)
         {
+            qCDebug(procLog) << "Logging out from pty";
             d->pty->logout();
             disconnect(SIGNAL(stateChanged(QProcess::ProcessState)),
                     this, SLOT(_k_onStateChanged(QProcess::ProcessState)));
@@ -87,11 +102,11 @@ KPtyProcess::~KPtyProcess()
     waitForFinished(300); // give it some time to finish
     if (state() != QProcess::NotRunning)
     {
-        qWarning() << Q_FUNC_INFO << "the terminal process is still running, trying to stop it by SIGHUP";
+        qCWarning(procLog) << Q_FUNC_INFO << "the terminal process is still running, trying to stop it by SIGHUP";
         ::kill(pid(), SIGHUP);
         waitForFinished(300);
         if (state() != QProcess::NotRunning)
-            qCritical() << Q_FUNC_INFO << "process didn't stop upon SIGHUP and will be SIGKILL-ed";
+            qCCritical(procLog) << Q_FUNC_INFO << "process didn't stop upon SIGHUP and will be SIGKILL-ed";
     }
 }
 
@@ -99,12 +114,13 @@ void KPtyProcess::setPtyChannels(PtyChannels channels)
 {
     Q_D(KPtyProcess);
 
-    qDebug() << "Setting PTY channels:" << channels;
+    qCDebug(procLog) << "Setting PTY channels:" << channels;
     d->ptyChannels = channels;
 }
 
 KPtyProcess::PtyChannels KPtyProcess::ptyChannels() const
 {
+    qCDebug(procLog) << "ptyChannels";
     Q_D(const KPtyProcess);
 
     return d->ptyChannels;
@@ -114,12 +130,13 @@ void KPtyProcess::setUseUtmp(bool value)
 {
     Q_D(KPtyProcess);
 
-    qDebug() << "Setting use utmp to:" << value;
+    qCDebug(procLog) << "Setting use utmp to:" << value;
     d->addUtmp = value;
 }
 
 bool KPtyProcess::isUseUtmp() const
 {
+    qCDebug(procLog) << "isUseUtmp";
     Q_D(const KPtyProcess);
 
     return d->addUtmp;
@@ -127,6 +144,7 @@ bool KPtyProcess::isUseUtmp() const
 
 KPtyDevice *KPtyProcess::pty() const
 {
+    qCDebug(procLog) << "pty";
     Q_D(const KPtyProcess);
 
     return d->pty;
@@ -136,9 +154,10 @@ KPtyDevice *KPtyProcess::pty() const
 void KPtyProcess::setupChildProcess()
 #else
 void KPtyProcess::setupChildProcessImpl()
+#endif
 {
     Q_D(KPtyProcess);
-    qDebug() << "Setting up child process PTY channels:" << d->ptyChannels;
+    qCDebug(procLog) << "Setting up child process PTY channels:" << d->ptyChannels;
 
     d->pty->setCTty();
 
@@ -159,6 +178,5 @@ void KPtyProcess::setupChildProcessImpl()
     KProcess::setupChildProcess();
 #endif
 }
-#endif
 
 //#include "kptyprocess.moc"
