@@ -29,22 +29,27 @@ void SingleInstallerApplication::activateWindow()
 {
     qCDebug(appLog) << "Activating window, mode:" << mode;
     if (!m_ddimFiles.isEmpty()) {
+        qCDebug(appLog) << "DDIM files found, setting mode to DdimChannel";
         mode = DdimChannel;
     } else {
+        qCDebug(appLog) << "No DDIM files found, setting mode to NormalChannel";
         mode = NormalChannel;
     }
 
     if (nullptr == m_qspMainWnd.get()) {
+        qCDebug(appLog) << "Main window is not initialized, creating new DebInstaller";
         m_qspMainWnd.reset(new DebInstaller());
         Dtk::Widget::moveToCenter(m_qspMainWnd.get());
         m_qspMainWnd->show();
     } else {
+        qCDebug(appLog) << "Main window is already initialized, activating window";
         m_qspMainWnd->setWindowState(Qt::WindowActive);
         m_qspMainWnd->activateWindow();  // Reactive main window
         m_qspMainWnd->showNormal();      // 非特效模式下激活窗口
     }
 
     if (bIsDbus) {
+        qCDebug(appLog) << "UAB backend is enabled, initializing UAB backend";
         // init uab backend synchronous on bus mode, but must be initialized after deb backend.
         // sa PackageAnalyzer::instance()
         Uab::UabBackend::instance()->initBackend(false);
@@ -65,11 +70,14 @@ void SingleInstallerApplication::InstallerDeb(const QStringList &debPathList)
 {
     qCInfo(appLog) << "InstallerDeb called with" << debPathList.size() << "packages";
     if (mode == DdimChannel) {
+        qCDebug(appLog) << "DdimChannel mode, invoking slotDdimSelected";
         QMetaObject::invokeMethod(m_qspMainWnd.get(), "slotDdimSelected", Qt::QueuedConnection, Q_ARG(QStringList, debPathList));
     } else if (debPathList.size() > 0) {
+        qCDebug(appLog) << "NormalChannel mode, invoking slotPackagesSelected";
         QMetaObject::invokeMethod(
             m_qspMainWnd.get(), "slotPackagesSelected", Qt::QueuedConnection, Q_ARG(QStringList, debPathList));
     } else {
+        qCDebug(appLog) << "No packages selected, activating window";
         if (m_qspMainWnd.get()) {                  // 先判断当前是否已经存在一个进程。
             m_qspMainWnd.get()->activateWindow();  // 特效模式下激活窗口
             m_qspMainWnd.get()->showNormal();      // 无特效激活窗口
@@ -111,37 +119,45 @@ QString SingleInstallerApplication::unInstallDebPackge(const QString &debPath)
 
 int SingleInstallerApplication::checkInstallStatus(const QString &debPath)
 {
+    qCDebug(appLog) << "Checking install status for:" << debPath;
     int ret;
     // 获取包安装状态
     QMetaObject::invokeMethod(
         m_qspMainWnd.get(), "checkInstallStatus", Qt::DirectConnection, Q_RETURN_ARG(int, ret), Q_ARG(QString, debPath));
+    qCDebug(appLog) << "Install status:" << ret;
     return ret;
 }
 
 int SingleInstallerApplication::checkDependsStatus(const QString &debPath)
 {
+    qCDebug(appLog) << "Checking dependency status for:" << debPath;
     int ret;
     // 获取包依赖状态
     QMetaObject::invokeMethod(
         m_qspMainWnd.get(), "checkDependsStatus", Qt::DirectConnection, Q_RETURN_ARG(int, ret), Q_ARG(QString, debPath));
+    qCDebug(appLog) << "Dependency status:" << ret;
     return ret;
 }
 
 int SingleInstallerApplication::checkDigitalSignature(const QString &debPath)
 {
+    qCDebug(appLog) << "Checking digital signature for:" << debPath;
     int ret;
     // 获取包依赖状态
     QMetaObject::invokeMethod(
         m_qspMainWnd.get(), "checkDigitalSignature", Qt::DirectConnection, Q_RETURN_ARG(int, ret), Q_ARG(QString, debPath));
+    qCDebug(appLog) << "Digital signature status:" << ret;
     return ret;
 }
 
 QString SingleInstallerApplication::getPackageInfo(const QString &debPath)
 {
+    qCDebug(appLog) << "Getting package info for:" << debPath;
     QString ret;
     // 获取包信息
     QMetaObject::invokeMethod(
         m_qspMainWnd.get(), "getPackageInfo", Qt::DirectConnection, Q_RETURN_ARG(QString, ret), Q_ARG(QString, debPath));
+    qCDebug(appLog) << "Package info retrieved";
     return ret;
 }
 
@@ -179,6 +195,7 @@ bool SingleInstallerApplication::parseCmdLine()
         qCInfo(appLog) << "Registered D-Bus service successfully";
         const QStringList paraList = parser.positionalArguments();
         if (paraList.isEmpty()) {
+            qCDebug(appLog) << "No packages selected, returning false";
             // hide main window on dbus
             if (parser.isSet("dbus")) {
                 bIsDbus = true;
@@ -196,11 +213,14 @@ bool SingleInstallerApplication::parseCmdLine()
             }
 
             if (!paraList.isEmpty() && m_selectedFiles.isEmpty() && m_ddimFiles.isEmpty()) {
+                qCDebug(appLog) << "No packages selected, returning false";
                 return false;
             }
         }
+        qCDebug(appLog) << "Processing" << paraList.size() << "package files, returning true";
         return true;
     }
 
+    qCDebug(appLog) << "No packages selected, returning true";
     return true;
 }
