@@ -4,9 +4,10 @@
 
 #include "droundbgframe.h"
 #include "utils/utils.h"
+#include "utils/ddlog.h"
 
 #include <DStyleHelper>
-#include <DApplicationHelper>
+#include <DGuiApplicationHelper>
 
 #include <QPainter>
 #include <QPainterPath>
@@ -18,18 +19,22 @@ DRoundBgFrame::DRoundBgFrame(QWidget *parent, int bgOffsetTop, int bgOffsetBotto
     , m_bgOffsetTop(bgOffsetTop)
     , m_bgOffsetBottom(bgOffsetBottom)
 {
+    qCDebug(appLog) << "Initializing DRoundBgFrame with offsets - top:" << bgOffsetTop << "bottom:" << bgOffsetBottom;
     // 添加accessibleName
     this->setObjectName("DRoundBgFrame");
     this->setAccessibleName("DRoundBgFrame");
+    qCDebug(appLog) << "DRoundBgFrame initialized";
 }
 
 void DRoundBgFrame::paintEvent(QPaintEvent *event)
 {
     Q_UNUSED(event)
+    qCDebug(appLog) << "Painting DRoundBgFrame";
 
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing, true);  // 设置边缘抗锯齿
     DPalette pa = DebApplicationHelper::instance()->palette(this);
+    qCDebug(appLog) << "Using palette color:" << pa.color(DPalette::Base).name();
 
     QPainterPath path;
     QRectF rect = this->rect();
@@ -37,6 +42,7 @@ void DRoundBgFrame::paintEvent(QPaintEvent *event)
     rect.setY(m_bgOffsetTop);                          // 设置y位置
     rect.setWidth(rect.width());                       // 设置宽度
     rect.setHeight(rect.height() - m_bgOffsetBottom);  // 设置高度
+    qCDebug(appLog) << "Painting rounded rect at:" << rect << "with radius 8";
 
     path.addRoundedRect(rect, 8, 8);
     painter.fillPath(path, QBrush(pa.color(DPalette::Base)));  // 填充颜色
